package Hawat::Controller::Unauth;
use strict;
use warnings;
use Moose;
use namespace::autoclean;

use Data::Dumper;
use Mentat::Core qw(:c_hawat);

#-------------------------------------------------------------------------------
# Initialization section
#-------------------------------------------------------------------------------

BEGIN { extends 'Hawat::Controller::Base'; }

__PACKAGE__->config(
    class       => 'Hawat::Controller::Unauth',
    constructor => 'new',
);

=head1 NAME

Hawat::Controller::Unauth - Catalyst controller for unauth access to restricted resources

=head1 DESCRIPTION

Catalyst controller for handling actions related to unauth access to restricted resources

=head1 ACTIONS

=cut

#-------------------------------------------------------------------------------
# Implementation section
#-------------------------------------------------------------------------------

=head2 report

View the report

=cut

sub report :Local {
    my ($self, $c, $hash) = @_;

    $c->detach(HAWAT_ERROR_HANDLER, [message => "Report access hash must be given as argument", menu => 'welcome']) unless $hash;
    $c->detach(HAWAT_ERROR_HANDLER, [message => "Invalid report access hash received as argument", menu => 'welcome']) unless $hash =~ /[-_a-zA-Z0-9]{20}/;

    # !!! This will NOT work, authentication will kick in
    #$c->controller('Event')->action_for('export'));
    # We must call the action method manually without the framework overhead
    $c->controller('Report')->view($c, $hash);
}

=head2 report_data

Download the report data

=cut

sub report_data :Local {
    my ($self, $c, $hash, $type) = @_;

    $c->detach(HAWAT_ERROR_HANDLER, [message => "Report access hash must be given as argument", menu => 'welcome']) unless $hash;
    $c->detach(HAWAT_ERROR_HANDLER, [message => "Invalid report access hash received as argument", menu => 'welcome']) unless $hash =~ /[-_a-zA-Z0-9]{20}/;

    # !!! This will NOT work, authentication will kick in
    #$c->controller('Event')->action_for('export'));
    # We must call the action method manually without the framework overhead
    $c->controller('Report')->data($c, $hash, $type);
}

=head2 report_events

Download the report events

=cut

sub report_alerts :Local {
    my ($self, $c, $hash, $alert) = @_;

    $c->detach(HAWAT_ERROR_HANDLER, [message => "Report access hash must be given as argument", menu => 'welcome']) unless $hash;
    $c->detach(HAWAT_ERROR_HANDLER, [message => "Invalid report access hash received as argument", menu => 'welcome']) unless $hash =~ /[-_a-zA-Z0-9]{20}/;

    # !!! This will NOT work, authentication will kick in
    #$c->controller('Event')->action_for('export'));
    # We must call the action method manually without the framework overhead
    $c->controller('Report')->alerts($c, $hash, $alert);
}

=head1 AUTHOR

 Jan Mach
 Cesnet, z.s.p.o
 jan.mach@cesnet.cz
 http://www.cesnet.cz

=head1 LICENSE

This library is free software. You can redistribute it and/or modify
it under the same terms as Perl itself.

=cut

__PACKAGE__->meta->make_immutable;

1;
